@@ -163,11 +163,17 @@ bool nfs_compare_clientcred(nfs_client_cred_t *cred1,
 			&cred2_cred_name, NULL, NULL, NULL, NULL, NULL, NULL);
 
 		if (maj_stat != GSS_S_COMPLETE &&
-		    maj_stat != GSS_S_CONTEXT_EXPIRED)
+		    maj_stat != GSS_S_CONTEXT_EXPIRED) {
+			gss_release_name(&min_stat, &cred1_cred_name);
 			return false;
+		}
 
 		maj_stat = gss_compare_name(&min_stat, cred1_cred_name,
 					    cred2_cred_name, &status);
+		/* release the names */
+		gss_release_name(&min_stat, &cred1_cred_name);
+		gss_release_name(&min_stat, &cred2_cred_name);
+
 		if (maj_stat != GSS_S_COMPLETE)
 			return false;
 
@@ -322,7 +328,7 @@ nfsstat4 nfs_req_creds(struct svc_req *req)
 					   &op_ctx->original_creds.caller_gid)
 			   ) {
 #endif
-				LogWarn(COMPONENT_IDMAPPER,
+				LogInfo(COMPONENT_IDMAPPER,
 					"Could not map principal %s to uid",
 					principal);
 				/* For compatibility with Linux knfsd, we set
@@ -788,6 +794,13 @@ fsal_errors_t nfs_access_op(struct fsal_obj_handle *obj,
 		if (access_allowed & FSAL_ACE_PERM_EXECUTE)
 			*granted_access |= ACCESS3_LOOKUP | ACCESS3_EXECUTE;
 
+		/* Allow only read if client has read only access
+		 * on this share.
+		 */
+		if (!(op_ctx->export_perms->options &
+		    EXPORT_OPTION_WRITE_ACCESS))
+			*granted_access &= ~(ACCESS3_EXTEND | ACCESS3_MODIFY |
+					   ACCESS3_DELETE);
 		/* Don't allow any bits that weren't set on request or
 		 * allowed by the file type.
 		 */
